@@ -9,7 +9,7 @@ from its submodules.  These are:
   :class:`base.ArrowLine`, :meth:`base.closeall`, :meth:`base.figure`,
   :meth:`base.load_csv`, :meth:`base.save`, :meth:`base.saveall`, :meth:`base.setup_subplots`
 
-- To manage simulation experiments:  :class:`exps.Experiment`,
+- To manage simulation experiments:  :class:`exps.Experiment`, :mod:`exps.doe`,
   :meth:`exps.gen_experiments`, :class:`exps.ParamDict`,
   :meth:`exps.read_params`, :meth:`exps.run_models`, :meth:`exps.write_params`,
   :meth:`exps.write_script`
@@ -30,7 +30,7 @@ __author__ = "Kevin Davies"
 __email__ = "kdavies4@gmail.com"
 __copyright__ = "Copyright 2012-2013, Georgia Tech Research Corporation"
 __license__ = "BSD-compatible (see LICENSE.txt)"
-__version__ = "0.6.2"
+__version__ = "0.7.0"
 
 
 import sys
@@ -55,7 +55,8 @@ from base import (add_arrows, add_hlines, add_vlines, animate, ArrowLine,
                  closeall, figure, load_csv, save, saveall, setup_subplots)
 from exps import (Experiment, gen_experiments, ParamDict, read_params,
                   run_models, write_params, write_script)
+import exps.doe as doe
 from linres import LinRes
-from multi import multiload, multiplot
+from multi import multiload, multiplot, multibode, multinyquist
 from simres import SimRes
 from texunit import label_number, label_quantity, unit2tex
