@@ -361,7 +361,8 @@ def color(ax, c, *args, **kwargs):
 
     - *c*: color- or c-axis data (2D array)
 
-    - *\*args*, *\*\*kwargs*: Additional arguments for  :meth:`matplotlib.pyplot.imshow`
+    - *\*args*, *\*\*kwargs*: Additional arguments for
+      :meth:`matplotlib.pyplot.imshow`
 
     **Example:**
 
@@ -528,7 +529,8 @@ def figure(label='', *args, **kwargs):
 
     - *label*: String to apply to the figure's *label* property
 
-    - *\*args*, *\*\*kwargs*: Additional arguments for  :meth:`matplotlib.pyplot.figure`
+    - *\*args*, *\*\*kwargs*: Additional arguments for
+      :meth:`matplotlib.pyplot.figure`
 
     **Example:**
 
@@ -721,7 +723,7 @@ def load_csv(fname, header_row=0, first_data_row=None,
          made to cast each column into :class:`int`, :class:`float`, and
          :class:`str` (in that order).
 
-    - *\*\*kwargs*: Additional arguments for  :meth:`csv.reader`
+    - *\*\*kwargs*: Additional arguments for :meth:`csv.reader`
 
     **Example:**
 
@@ -831,7 +833,7 @@ def plot(y, x=None, ax=None, label=None,
 
          .. Seealso:: http://matplotlib.sourceforge.net/api/collections_api.html
 
-    - *\*\*kwargs*: Additional arguments for  :meth:`matplotlib.pyplot.plot`
+    - *\*\*kwargs*: Additional arguments for :meth:`matplotlib.pyplot.plot`
 
     **Returns:** List of :class:`matplotlib.lines.Line2D` objects
 
@@ -935,7 +937,7 @@ def quiver(ax, u, v, x=None, y=None, pad=0.05, pivot='middle', **kwargs):
 
     - *pivot*: "tail" | "middle" | "tip" (see :meth:`matplotlib.pyplot.quiver`)
 
-    - *\*\*kwargs*: Additional arguments for  :meth:`matplotlib.pyplot.quiver`
+    - *\*\*kwargs*: Additional arguments for :meth:`matplotlib.pyplot.quiver`
 
     **Example:**
 
@@ -1038,22 +1040,19 @@ def save(formats=['pdf', 'png'], fbase='1'):
 
     # Save the figures, creating folders as necessary.
     (directory, fbase_fig) = os.path.split(plt.getp(fig, 'label'))
-    if fbase_fig == '':
-        if directory == '':
-            if chosen_directory is None:
-                # Initialize a dummy wx.App instance.  Dialogs can only be
-                # called after this is done
-                # [http://code.google.com/p/easywx/, accessed 10/7/2012].
-                #app = App()
-                chosen_directory = DirSelector(
-                    "Choose a directory for the images.",
-                    defaultPath=os.path.join(*['..']*4))
-                if chosen_directory == '':
-                    return
-            directory = chosen_directory
+    if not fbase_fig:
+        if not directory:
+            # Initialize a dummy wx.App instance.  Dialogs can only be
+            # called after this is done
+            # [http://code.google.com/p/easywx/, accessed 10/7/2012].
+            #app = App()
+            directory = DirSelector("Choose a directory for the images.",
+                                    defaultPath=os.path.join(*['..']*4))
+            if not directory:
+                return
     else:
         fbase = fbase_fig
-    if directory != '' and not os.path.isdir(directory):
+    if directory and not os.path.isdir(directory):
         os.mkdir(directory)
     for format in formats:
         fname = os.path.join(directory, fbase + '.' + format)
@@ -1117,10 +1116,10 @@ def saveall(formats=['pdf', 'png']):
     i = 0
     for fig in figs:
         (directory, fbase) = os.path.split(plt.getp(fig, 'label'))
-        if fbase == '':
+        if not fbase:
             fbase = str(i)
             i += 1
-            if directory == '':
+            if not directory:
                 if chosen_directory is None:
                     # Initialize a dummy wx.App instance.  Dialogs can only be
                     # called after this is done
@@ -1129,10 +1128,10 @@ def saveall(formats=['pdf', 'png']):
                     chosen_directory = DirSelector(
                         "Choose a directory for the images.",
                         defaultPath=os.path.join(*['..']*4))
-                    if chosen_directory == '':
+                    if not chosen_directory:
                         return
                 directory = chosen_directory
-        if directory != '' and not os.path.isdir(directory):
+        if directory and not os.path.isdir(directory):
             os.mkdir(directory)
         for format in formats:
             fname = os.path.join(directory, fbase + '.' + format)
